import Foundation
import TIM
import TIMEncryptedStorage
import AppAuth

private let scopes = [OIDScopeOpenID, OIDScopeProfile]
private let testUrl = "https://oidc-test.hosted.trifork.com/auth/realms/gravid"
private let prodUrl = "https://oidc.hosted.trifork.com/auth/realms/gravid"
private let clientIdMock = "gravidappmock"
private let clientId = "gravidapp"

extension TIMConfiguration {
    static func forBuildConfiguration(_ config: BuildConfiguration) -> TIMConfiguration {
        switch config {
        case .debug, .testMock:
            return TIMConfiguration(
                oidc: TIMOpenIDConfiguration(
                    issuer: URL(string: testUrl)!,
                    clientId: clientIdMock,
                    redirectUri: URL(string: "\(clientIdMock):/")!,
                    scopes: scopes
                ),
                keyService: TIMKeyServiceConfiguration(
                    realmBaseUrl: testUrl,
                    version: .v1
                )
            )
        case .test:
            return TIMConfiguration(
                oidc: TIMOpenIDConfiguration(
                    issuer: URL(string: testUrl)!,
                    clientId: clientId,
                    redirectUri: URL(string: "\(clientId):/")!,
                    scopes: scopes
                ),
                keyService: TIMKeyServiceConfiguration(
                    realmBaseUrl: testUrl,
                    version: .v1
                )
            )
        case .release:
            return TIMConfiguration(
                oidc: TIMOpenIDConfiguration(
                    issuer: URL(string: prodUrl)!,
                    clientId: clientId,
                    redirectUri: URL(string: "\(clientId):/")!,
                    scopes: scopes
                ),
                keyService: TIMKeyServiceConfiguration(
                    realmBaseUrl: prodUrl,
                    version: .v1
                )
            )
        case .unknown:
            fatalError("Build config is not available.")
        }

    }
}
