//
//  UILabel+Extensions.swift
//  MinGraviditet
//
//  Created by Thomas Kalhøj Clemensen on 09/10/2020.
//

import UIKit
import TriforkSwiftExtensions
import SwiftUI

extension UILabel {
    convenience init(fontStyle: FontStyle, text: String? = nil, color: UIColor? = nil) {
        self.init()
        self.numberOfLines = 0
        self.translatesAutoresizingMaskIntoConstraints = false

        setText(text ?? "", with: fontStyle, color: color)
    }

    func setText(_ text: String, with fontStyle: FontStyle, color: UIColor? = nil) {
        self.textColor = color // Save color for later use of 'nil' values

        if fontStyle.requiresAttributedString() {
            var options: [StringFormatOption] = []
            if let lineSpacing = fontStyle.lineSpacing {
                options.append(.lineSpacing(lineSpacing))
            }
            if let letterSpacing = fontStyle.letterSpacing {
                options.append(.letterSpacing(letterSpacing))
            }
            options.append(.textColor(color ?? (textColor ?? .black)))
            options.append(.font(fontStyle.scaledFont()))
            self.attributedText = text.convertToAttributed(withOptions: options)
        } else {
            self.font = fontStyle.scaledFont()
            self.text = text
        }
    }
}
