//
//  FlashLogger.swift
//  MinGraviditet
//
//  Created by Thomas Kalhøj Clemensen on 13/10/2020.
//

import UIKit
import TriforkSwiftLogger
import os.log

final class ErrorFlashLogger : LoggerProtocol {

    func log(_ message: String, at level: OSLogType, file: String, function: String, line: UInt, category: String?) {
        let color: UIColor?
        switch level {
        case .error:
            color = .orange
        case .fault:
            color = .red
        default:
            color = nil
        }

        if  let color = color,
            let keyWindow = UIApplication.shared.windows.first(where: { $0.isKeyWindow }) {
            let flashView = UIView()
            flashView.backgroundColor = color
            flashView.frame = keyWindow.bounds
            keyWindow.addSubview(flashView)

            UIView.animate(withDuration: 0.2, delay: 0.0, options: .curveEaseIn) {
                flashView.alpha = 0.0
            } completion: { (_) in
                flashView.removeFromSuperview()
            }
        }
    }
}
