//
//  FontStyle.swift
//  MinGraviditet
//
//  Created by Thomas Kalhøj Clemensen on 09/10/2020.
//

import UIKit

struct FontStyle {
    let font: UIFont
    let textStyle: UIFont.TextStyle
    let lineSpacing: CGFloat?
    let letterSpacing: CGFloat?

    init(font: UIFont, textStyle: UIFont.TextStyle, lineSpacing: CGFloat? = nil, letterSpacing: CGFloat? = nil) {
        self.font = font
        self.textStyle = textStyle
        self.lineSpacing = lineSpacing
        self.letterSpacing = letterSpacing
    }

    func requiresAttributedString() -> Bool {
        lineSpacing == nil || letterSpacing == nil
    }

    func scaledFont() -> UIFont {
        let fontMetrics: UIFontMetrics
        if textStyle.rawValue.starts(with: "UICT") {
            fontMetrics = UIFontMetrics(forTextStyle: textStyle)
        } else {
            fontMetrics = UIFontMetrics.default
        }
        return fontMetrics.scaledFont(for: font)
    }
}

extension FontStyle {

    // MARK: - Titles
    static let title = FontStyle(
        font: R.font.ptSansBold(size: 32)!,
        textStyle: .title1
    )

    static let inlineTitle = FontStyle(
        font: R.font.ptSansBold(size: 20)!,
        textStyle: .title2
    )

    static let navigationBarTitle = FontStyle(
        font: R.font.ptSansBold(size: 16)!,
        textStyle: .title1
    )

    // MARK: - Text

    static let body = FontStyle(
        font: R.font.ptSansRegular(size: 16.0)!,
        textStyle: .body
    )

    // MARK: - Custom controls

    static let button = FontStyle(
        font: R.font.ptSansBold(size: 16)!,
        textStyle: .callout
    )

}
