//
//  BaseView.swift
//  MinGraviditet
//
//  Created by Thomas Kalhøj Clemensen on 08/10/2020.
//

import UIKit
import SwiftUI

class BaseView : UIView {

    weak var parentViewController: UIViewController?

    let contentView = UIView(translatesAutoresizingMask: false)

    init(parentViewController: UIViewController) {
        super.init(frame: .zero)
        self.parentViewController = parentViewController
        setupBaseView()
    }

    override init(frame: CGRect) {
        super.init(frame: frame)
        setupBaseView()
    }

    required init?(coder: NSCoder) {
        super.init(coder: coder)
        setupBaseView()
    }

    private func setupBaseView() {
        backgroundColor = R.color.mainBackground()
        setupContentView()
        setupView()
    }

    private func setupContentView() {
        addSubview(contentView)
        NSLayoutConstraint.activate([
            contentView.topAnchor.constraint(equalTo: safeAreaLayoutGuide.topAnchor),
            contentView.bottomAnchor.constraint(equalTo: safeAreaLayoutGuide.bottomAnchor),
            contentView.leadingAnchor.constraint(equalTo: safeAreaLayoutGuide.leadingAnchor),
            contentView.trailingAnchor.constraint(equalTo: safeAreaLayoutGuide.trailingAnchor)
        ])
    }

    func setupView() {
        // Override in subclass
    }

    func addVerticalStackToContentView(systemSpacingInset: UIEdgeInsets = .zero) -> UIStackView {
        let stack = UIStackView(arrangedSubviews: [], axis: .vertical)
        stack.translatesAutoresizingMaskIntoConstraints = false
        contentView.addSubview(stack)
        NSLayoutConstraint.activate([
            stack.topAnchor.constraint(equalToSystemSpacingBelow: contentView.topAnchor, multiplier: systemSpacingInset.top),
            stack.leadingAnchor.constraint(equalToSystemSpacingAfter: contentView.leadingAnchor, multiplier: systemSpacingInset.left),
            contentView.trailingAnchor.constraint(equalToSystemSpacingAfter: stack.trailingAnchor, multiplier: systemSpacingInset.right),
            contentView.bottomAnchor.constraint(equalToSystemSpacingBelow: stack.bottomAnchor, multiplier: systemSpacingInset.bottom)
        ])
        return stack
    }

}
