import SwiftUI

struct OnboardingConsentView: View {
    @Environment(\.presentationMode) var presentationMode

    @ObservedObject var viewModel = OnboardingConsentView.ViewModel()

    var body: some View {
        NavigationView {
            VStack {
                ScrollView {
                    VStack(alignment: .leading, spacing: 10) {
                        Text(R.string.localizable.agreement_header1())
                            .applyFontStyle(fontStyle: .inlineTitle)
                        Text(R.string.localizable.agreement_text1())
                            .applyFontStyle(fontStyle: .body)
                        Text(R.string.localizable.agreement_header2())
                            .applyFontStyle(fontStyle: .inlineTitle)
                        Text(R.string.localizable.agreement_text2())
                            .applyFontStyle(fontStyle: .body)
                    }
                    .padding()
                }
                SUIButton<PrimaryButton>(title: R.string.localizable.agreement_button_text()) {
                    viewModel.performOpenIDConnectLogin()
                }
                .frame(height: Metrics.Sizes.buttonHeight)
                .padding()
                .alert(isPresented: $viewModel.oidcLoginFailed, content: {
                    Alert(
                        title: Text(R.string.localizable.common_alert_title_error()),
                        message: Text(R.string.localizable.common_alert_message_generic()),
                        dismissButton: .default(Text(R.string.localizable.common_ok()))
                    )
                })
            }
            .navigationBarTitle(Text(R.string.localizable.agreement_title()), displayMode: .inline)
            .navigationBarItems(trailing:
                                    Button(action: {
                                        presentationMode.wrappedValue.dismiss()
                                    }, label: {
                                        Image(uiImage: R.image.close()!)
                                    })
            )
        }
    }
}

struct OnboardingConsentView_Previews: PreviewProvider {
    static var previews: some View {
        OnboardingConsentView()
    }
}
