import Foundation
import TIM
import Combine
import TriforkSwiftDependencyInjection

extension OnboardingConsentView {
    final class ViewModel: ObservableObject {
        private var cancelBag = CancelBag()
        @Inject private var logger: Logger
        @Inject private var timAuth: TIMAuth

        @Published var oidcLoginFailed: Bool = false
        @Published var oidcLoginSucceded: Bool = false
        @Published var userId: String?

        func performOpenIDConnectLogin() {
            guard let rootViewController = App.windowRootViewController else {
                return
            }
            self.oidcLoginFailed = false
            self.oidcLoginSucceded = false

            timAuth.performOpenIDConnectLogin(presentingViewController: rootViewController)
                .sink { (completion) in
                    switch completion {
                    case .failure(let error):
                        self.logger.error("Failed to login with OIDC: \(error.localizedDescription)")
                        self.oidcLoginFailed = true
                    case .finished:
                        guard let userId = self.userId else {
                            self.oidcLoginSucceded = false
                            self.oidcLoginFailed = true
                            return
                        }
                        NotificationCenter.default.post(
                            name: NSNotification.Name.SceneDelegate.changeRootViewController,
                            object: SceneDelegate.NotificationMessage.beginRegisterFlow(userId: userId)
                        )
                    }
                } receiveValue: { (accessToken) in
                    self.logger.default("Received access token from OIDC login: \(accessToken)")
                    self.userId = accessToken.userId
                }.store(in: &cancelBag)

        }
    }
}
