import SwiftUI
import TriforkSwiftDependencyInjection
import TIM

struct OnboardingView: View {
    @Inject private var logger: Logger

    @ObservedObject var viewModel = OnboardingView.ViewModel()

    var body: some View {
        NavigationView {
            VStack {
                GeometryReader { geo in
                    SUIScrollView(viewModel: $viewModel.scrollViewModel) {
                        HStack(spacing: 0) {
                            ForEach(viewModel.steps.indices) { index in
                                OnboardingStepView(viewModel: viewModel.steps[index])
                                    .tag(index)
                                    .frame(
                                        width: geo.size.width,
                                        height: geo.size.height
                                    )
                            }
                        }
                    }
                }
                Spacer()
                PageIndicators(numberOfPages: viewModel.steps.count, currentIndex: viewModel.scrollViewModel.currentPage)
                Spacer(minLength: 20)
                VStack {
                    SUIButton<PrimaryButton>(title: R.string.localizable.onboarding_login_nemid_button()) {
                        viewModel.presentConsent = true
                    }
                    .frame(height: Metrics.Sizes.buttonHeight)
                    SUIButton<SecondaryButton>(title: R.string.localizable.onboarding_login_get_started_button()) {
                        logger.default("ACTION! 🥳")
                    }
                    .frame(height: Metrics.Sizes.buttonHeight)
                }.padding()
            }
            .sheet(isPresented: $viewModel.presentConsent, content: {
                OnboardingConsentView()
            })
            .navigationBarHidden(true)
        }
    }
}

struct OnboardingView_Previews: PreviewProvider {
    static var previews: some View {
        Group {
            OnboardingView()
                .previewDevice("iPhone 12 Pro")

            OnboardingView()
                .previewDevice("iPhone SE")
        }
    }
}
