import UIKit
import SwiftUI

class CustomButton : UIButton {

    override var isSelected: Bool {
        didSet {
            updateForState()
        }
    }

    override var isHighlighted: Bool {
        didSet {
            updateForState()
        }
    }

    override var isEnabled: Bool {
        didSet {
            updateForState()
        }
    }

    var action: (() -> Void)?

    override init(frame: CGRect) {
        super.init(frame: frame)
        internalSetup()
    }

    required init?(coder: NSCoder) {
        super.init(coder: coder)
        internalSetup()
    }

    private func internalSetup() {
        addTarget(self, action: #selector(tapped(_:)), for: .touchUpInside)
        setup()
    }

    func setup() {
        // Override
    }

    private func updateForState() {
        if !isEnabled {
            alpha = 0.5
        } else {
            alpha = isHighlighted || isSelected ? 0.8 : 1.0
        }
    }

    override func setTitle(_ title: String?, for state: UIControl.State) {
        super.setTitle(title, for: state)
        titleLabel?.font = FontStyle.button.scaledFont()
    }

    @objc func tapped(_ sender: PrimaryButton) {
        action?()
    }
}

struct SUIButton<T: CustomButton>: UIViewRepresentable {
    var title: String
    var action: (() -> Void)?

    func makeUIView(context: Context) -> T {
        T()
    }

    func updateUIView(_ uiView: T, context: Context) {
        uiView.action = action
        uiView.setTitle(title, for: .normal)
    }
}
