import UIKit
import SwiftUI

final class LoadingView : UIView {
    let activityIndicator = UIActivityIndicatorView(style: .large)
    let disclaimerLabel = UILabel(
        fontStyle: .title,
        text: "DENNE LOADING SPINNER ER MIDLERTIDIG!",
        color: .magenta
    )

    override init(frame: CGRect) {
        super.init(frame: frame)
        setup()
    }

    required init?(coder: NSCoder) {
        super.init(coder: coder)
        setup()
    }

    private func setup() {
        translatesAutoresizingMaskIntoConstraints = false
        activityIndicator.color = R.color.primary()
        activityIndicator.translatesAutoresizingMaskIntoConstraints = false
        addSubview(activityIndicator)
        addSubview(disclaimerLabel)
        disclaimerLabel.setContentCompressionResistancePriority(.required, for: .horizontal)
        disclaimerLabel.textAlignment = .center

        NSLayoutConstraint.activate([
            activityIndicator.topAnchor.constraint(equalTo: topAnchor),
            activityIndicator.centerXAnchor.constraint(equalTo: centerXAnchor),

            disclaimerLabel.topAnchor.constraint(equalTo: activityIndicator.bottomAnchor),
            disclaimerLabel.leadingAnchor.constraint(equalTo: leadingAnchor),
            disclaimerLabel.trailingAnchor.constraint(equalTo: trailingAnchor),
            disclaimerLabel.bottomAnchor.constraint(equalTo: bottomAnchor)
        ])
    }

    func start() {
        self.activityIndicator.startAnimating()
        self.alpha = 1.0
    }

    func stop() {
        self.activityIndicator.stopAnimating()
        self.alpha = 0.0
    }
}

struct SUILoadingView: UIViewRepresentable {
    var isLoading: Bool

    func makeUIView(context: Context) -> LoadingView {
        LoadingView()
    }

    func updateUIView(_ uiView: LoadingView, context: Context) {
        if isLoading {
            uiView.start()
        } else {
            uiView.stop()
        }
    }
}
