//
//  SwiftUIWrapper.swift
//  MinGraviditet
//
//  Created by Thomas Kalhøj Clemensen on 08/10/2020.
//

import UIKit
import SwiftUI

final class SwiftUIWrapperView<T>: UIView where T: View {
    let hostingController: UIHostingController<T>

    required init(swiftUiView: T, parentViewController: UIViewController) {
        hostingController = UIHostingController(rootView: swiftUiView)
        super.init(frame: .zero)
        self.translatesAutoresizingMaskIntoConstraints = false

        hostingController.view.frame = self.bounds
        hostingController.view.autoresizingMask = [.flexibleHeight, .flexibleWidth]
        addSubview(hostingController.view)
        parentViewController.addChild(hostingController)
    }

    override init(frame: CGRect) {
        fatalError("\(Self.self) has to be initialized with parent view controller.")
    }

    required init?(coder: NSCoder) {
        fatalError("\(Self.self) has to be initialized with parent view controller.")
    }

    override func removeFromSuperview() {
        hostingController.removeFromParent()
        hostingController.view.removeFromSuperview()
        super.removeFromSuperview()
    }
}
